==> aria2-1.9.5.tar.xz: aria2-1.9.5/src/FeedbackURISelector.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 nn * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_FEEDBACK_URI_SELECTOR_H_
#define _D_FEEDBACK_URI_SELECTOR_H_
#include "URISelector.h"
#include "SharedHandle.h"

namespace aria2 {

class ServerStatMan;

class FeedbackURISelector:public URISelector {
private:
  SharedHandle<ServerStatMan> serverStatMan_;

public:
  FeedbackURISelector(const SharedHandle<ServerStatMan>& serverStatMan);

  virtual ~FeedbackURISelector();

  virtual std::string select(FileEntry* fileEntry);
};

} // namespace aria2

#endif // _D_FEEDBACK_URI_SELECTOR_H_

==> aria2-1.10.1.tar.xz: aria2-1.10.1/src/FeedbackURISelector.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 nn * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_FEEDBACK_URI_SELECTOR_H_
#define _D_FEEDBACK_URI_SELECTOR_H_
#include "URISelector.h"
#include "SharedHandle.h"

namespace aria2 {

class ServerStatMan;
class Logger;

class FeedbackURISelector:public URISelector {
private:
  SharedHandle<ServerStatMan> serverStatMan_;

  Logger* logger_;

  std::string selectRarer
  (const std::deque<std::string>& uris,
   const std::vector<std::pair<size_t, std::string> >& usedHosts);

  std::string selectFaster
  (const std::deque<std::string>& uris,
   const std::vector<std::pair<size_t, std::string> >& usedHosts);
public:
  FeedbackURISelector(const SharedHandle<ServerStatMan>& serverStatMan);

  virtual ~FeedbackURISelector();

  // This function expects ignoreHosts are ordered in ascending order.
  virtual std::string select
  (FileEntry* fileEntry,
   const std::vector<std::pair<size_t, std::string> >& usedHosts);
};

} // namespace aria2

#endif // _D_FEEDBACK_URI_SELECTOR_H_
